@@ -4,14 +4,13 @@
 #' `requireInDateRange()` filters cohort records, keeping only those for
 #' which the index date is within the specified date range.
 #'
-#' @param cohort A cohort table in a cdm reference.
-#' @param dateRange A window of time during which the index date must have
-#' been observed.
-#' @param cohortId IDs of the cohorts to modify. If NULL, all cohorts will be
-#' used; otherwise, only the specified cohorts will be modified, and the
-#' rest will remain unchanged.
-#' @param indexDate Variable in cohort that contains the index date of interest
-#' @param name Name of the new cohort with the restriction.
+#' @inheritParams cohortDoc
+#' @inheritParams cohortIdModifyDoc
+#' @inheritParams nameDoc
+#' @param dateRange A date vector with the minimum and maximum dates between
+#' which the index date must have been observed.
+#' @param indexDate Name of the column in the cohort that contains the date of
+#' interest.
 #'
 #' @return The cohort table with any cohort entries outside of the date range
 #' dropped
@@ -31,40 +30,31 @@ requireInDateRange <- function(cohort,
                                cohortId = NULL,
                                indexDate = "cohort_start_date",
                                name = tableName(cohort)) {
-
   # checks
-  name <- validateName(name)
-  validateCohortTable(cohort)
-  cdm <- omopgenerics::cdmReference(cohort)
-  validateCDM(cdm)
+  name <- omopgenerics::validateNameArgument(name, validation = "warning")
+  cohort <- omopgenerics::validateCohortArgument(cohort)
   validateCohortColumn(indexDate, cohort, class = "Date")
-  ids <- omopgenerics::settings(cohort)$cohort_definition_id
-  cohortId <- validateCohortId(cohortId, ids)
-  validateDateRange(dateRange)
+  cdm <- omopgenerics::validateCdmArgument(omopgenerics::cdmReference(cohort))
+  cohortId <- validateCohortId(cohortId, settings(cohort))
+  dateRange <- validateDateRange(dateRange)
 
   # requirement
   if (!is.na(dateRange[1])) {
     cohort <- cohort |>
-      dplyr::filter(
-        .data[[indexDate]] >= !!dateRange[1] | (!.data$cohort_definition_id %in% cohortId)
-      ) |>
+      dplyr::filter(.data[[indexDate]] >= !!dateRange[1] |
+                      (!.data$cohort_definition_id %in% cohortId)) |>
       dplyr::compute(name = name, temporary = FALSE) |>
-      omopgenerics::recordCohortAttrition(
-        reason = paste0(indexDate, " after ", dateRange[1]),
-        cohortId = cohortId
-      )
+      omopgenerics::recordCohortAttrition(reason = paste0(indexDate, " after ", dateRange[1]),
+                                          cohortId = cohortId)
   }
 
   if (!is.na(dateRange[2])) {
     cohort <- cohort |>
-      dplyr::filter(
-        .data[[indexDate]] <= !!dateRange[2] | (!.data$cohort_definition_id %in% cohortId)
-      ) |>
+      dplyr::filter(.data[[indexDate]] <= !!dateRange[2] |
+                      (!.data$cohort_definition_id %in% cohortId)) |>
       dplyr::compute(name = name, temporary = FALSE) |>
-      omopgenerics::recordCohortAttrition(
-        reason = paste0(indexDate, " before ", dateRange[2]),
-        cohortId = cohortId
-      )
+      omopgenerics::recordCohortAttrition(reason = paste0(indexDate, " before ", dateRange[2]),
+                                          cohortId = cohortId)
   }
 
   cohort <- cohort |>
@@ -112,17 +102,14 @@ trimToDateRange <- function(cohort,
                             startDate = "cohort_start_date",
                             endDate = "cohort_end_date",
                             name = tableName(cohort)) {
-
   # checks
-  name <- validateName(name)
-  validateCohortTable(cohort)
-  cdm <- omopgenerics::cdmReference(cohort)
-  validateCDM(cdm)
+  name <- omopgenerics::validateNameArgument(name, validation = "warning")
+  cohort <- omopgenerics::validateCohortArgument(cohort)
   validateCohortColumn(startDate, cohort, class = "Date")
   validateCohortColumn(endDate, cohort, class = "Date")
-  ids <- omopgenerics::settings(cohort)$cohort_definition_id
-  cohortId <- validateCohortId(cohortId, ids)
-  validateDateRange(dateRange)
+  cdm <- omopgenerics::validateCdmArgument(omopgenerics::cdmReference(cohort))
+  cohortId <- validateCohortId(cohortId, settings(cohort))
+  dateRange <- validateDateRange(dateRange)
 
   # trim start
   if (!is.na(dateRange[1])) {
@@ -134,10 +121,8 @@ trimToDateRange <- function(cohort,
         minDate = dateRange[1]
       ) %>%
       dplyr::compute(name = name, temporary = FALSE) %>%
-      omopgenerics::recordCohortAttrition(
-        reason = paste0(startDate, " >= ", dateRange[1]),
-        cohortId = cohortId
-      )
+      omopgenerics::recordCohortAttrition(reason = paste0(startDate, " >= ", dateRange[1]),
+                                          cohortId = cohortId)
   }
 
   # trim end
@@ -150,10 +135,8 @@ trimToDateRange <- function(cohort,
         maxDate = dateRange[2]
       ) %>%
       dplyr::compute(name = name, temporary = FALSE) %>%
-      omopgenerics::recordCohortAttrition(
-        reason = paste0(endDate, " <= ", dateRange[2]),
-        cohortId = cohortId
-      )
+      omopgenerics::recordCohortAttrition(reason = paste0(endDate, " <= ", dateRange[2]),
+                                          cohortId = cohortId)
   }
 
   cohort <- cohort |>
@@ -169,15 +152,16 @@ trimStartDate <- function(cohort,
                           minDate,
                           requirementIds) {
   cohort <- cohort %>%
-    dplyr::mutate(!!startDate := dplyr::if_else(
-      .data[[startDate]] <= !!minDate &
-        .data$cohort_definition_id %in% .env$requirementIds,
-      as.Date(minDate), .data[[startDate]]
-    )) %>%
-    dplyr::filter(
-      .data[[startDate]] <= .data[[endDate]] |
-        (!.data$cohort_definition_id %in% .env$requirementIds)
-    )
+    dplyr::mutate(
+      !!startDate := dplyr::if_else(
+        .data[[startDate]] <= !!minDate &
+          .data$cohort_definition_id %in% .env$requirementIds,
+        as.Date(minDate),
+        .data[[startDate]]
+      )
+    ) %>%
+    dplyr::filter(.data[[startDate]] <= .data[[endDate]] |
+                    (!.data$cohort_definition_id %in% .env$requirementIds))
   return(cohort)
 }
 
@@ -190,11 +174,10 @@ trimEndDate <- function(cohort,
     dplyr::mutate(!!endDate := dplyr::if_else(
       .data[[endDate]] >= !!maxDate &
         (.data$cohort_definition_id %in% .env$requirementIds),
-      as.Date(maxDate), .data[[endDate]]
+      as.Date(maxDate),
+      .data[[endDate]]
     )) %>%
-    dplyr::filter(
-      .data[[startDate]] <= .data[[endDate]] |
-        (!.data$cohort_definition_id %in% requirementIds)
-    )
+    dplyr::filter(.data[[startDate]] <= .data[[endDate]] |
+                    (!.data$cohort_definition_id %in% requirementIds))
   return(cohort)
 }
