@@ -65,14 +65,14 @@ test_that("expected errors and messages", {
 test_that("simple example", {
   cdm <- omock::mockCdmReference() |>
     omock::mockCdmFromTables(tables = list("cohort" = dplyr::tibble(
-      "cohort_definition_id" = 1,
-      "subject_id" = c(1, 2, 3),
+      "cohort_definition_id" = 1L,
+      "subject_id" = c(1L, 2L, 3L),
       "cohort_start_date" = as.Date("2020-01-01"),
       "cohort_end_date" = as.Date("2029-12-31")
     )))
   cdm <- omopgenerics::insertTable(
     cdm = cdm, name = "concept", table = dplyr::tibble(
-      "concept_id" = 1,
+      "concept_id" = 1L,
       "concept_name" = "my concept",
       "domain_id" = "drUg",
       "vocabulary_id" = NA,
@@ -84,9 +84,9 @@ test_that("simple example", {
   )
   cdm <- omopgenerics::insertTable(
     cdm = cdm, name = "drug_exposure", table = dplyr::tibble(
-      "drug_exposure_id" = 1:11,
-      "person_id" = c(1, 1, 1, 1, 2, 2, 3, 1, 1, 1, 1),
-      "drug_concept_id" = c(1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1),
+      "drug_exposure_id" = 1:11 |> as.integer(),
+      "person_id" = c(1, 1, 1, 1, 2, 2, 3, 1, 1, 1, 1) |> as.integer(),
+      "drug_concept_id" = c(1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1) |> as.integer(),
       "drug_exposure_start_date" = c(0, 300, 1500, 750, 10, 800, 150, 1800, 1801, 1802, 1803),
       "drug_exposure_end_date" = c(400, 800, 1600, 1550, 2000, 1000, 600, 1801, 1802, 1803, 1804),
       "drug_type_concept_id" = 1
@@ -98,13 +98,38 @@ test_that("simple example", {
   )
 
   cdm <- cdm |> copyCdm()
-
-  expect_no_error(cohort <- conceptCohort(cdm = cdm, conceptSet = list(a = 1), name = "cohort"))
+  isDuckdb <- attr(omopgenerics::cdmSource(cdm), "source_type") == "duckdb"
+  if(isDuckdb){
+  startTempTables <- countDuckdbTempTables(
+    con = attr(omopgenerics::cdmSource(cdm),
+                               "dbcon"))
+  startPermanentTables <- countDuckdbPermanentTables(
+    con = attr(omopgenerics::cdmSource(cdm),
+               "dbcon"))
+  }
+  expect_no_error(cohort <- conceptCohort(cdm = cdm,
+                                          conceptSet = list(a = 1),
+                                          name = "my_cohort"))
+  if(isDuckdb){
+    endTempTables <- countDuckdbTempTables(
+      con = attr(omopgenerics::cdmSource(cdm),
+                 "dbcon"))
+    endPermanentTables <- countDuckdbPermanentTables(
+      con = attr(omopgenerics::cdmSource(cdm),
+                 "dbcon"))
+    # we should have only added 4 permanent tables (the new cohort table and
+    # three tables with settings, attrition, and codelist)
+    # no temp tables will have been created
+    expect_true(startTempTables == endTempTables)
+    expect_true(
+      startPermanentTables + 4 == endPermanentTables
+    )
+  }
 
   expect_true(cohort |> dplyr::tally() |> dplyr::pull() == 4)
   expect_true(cohortCount(cohort)$number_records == 4)
   expect_true(cohortCount(cohort)$number_subjects == 2)
-  expect_true(attrition(cohort) |> nrow() == 1)
+  # expect_true(attrition(cohort) |> nrow() == 1)
   expect_identical(
     settings(cohort),
     dplyr::tibble(
@@ -112,7 +137,7 @@ test_that("simple example", {
       "cdm_version" = attr(cdm, "cdm_version"), "vocabulary_version" = "mock"
       )
   )
-  expect_identical(cohortCodelist(cohort, 1), omopgenerics::newCodelist(list(a = 1)))
+  expect_identical(cohortCodelist(cohort, 1), omopgenerics::newCodelist(list(a = 1L)))
   cohort <- cohort |>
     dplyr::collect() |>
     dplyr::as_tibble() |>
@@ -176,7 +201,7 @@ test_that("simple example duckdb", {
   expect_true(cohort |> dplyr::tally() |> dplyr::pull() == 4)
   expect_true(cohortCount(cohort)$number_records == 4)
   expect_true(cohortCount(cohort)$number_subjects == 2)
-  expect_true(attrition(cohort) |> nrow() == 1)
+  # expect_true(attrition(cohort) |> nrow() == 1)
   expect_identical(
     settings(cohort),
     dplyr::tibble(
@@ -184,7 +209,7 @@ test_that("simple example duckdb", {
       "cdm_version" = attr(cdm, "cdm_version"), "vocabulary_version" = "mock"
       )
   )
-  expect_identical(cohortCodelist(cohort, 1), omopgenerics::newCodelist(list(a = 1)))
+  expect_identical(cohortCodelist(cohort, 1), omopgenerics::newCodelist(list(a = 1L)))
   cohort <- cohort |>
     dplyr::collect() |>
     dplyr::as_tibble() |>
@@ -283,8 +308,8 @@ test_that("excluded concepts in codelist", {
 test_that("out of observation", {
   testthat::skip_on_cran()
   cdm_local <- omock::mockCdmReference() |>
-    omock::mockPerson(n = 4) |>
-    omock::mockObservationPeriod()
+    omock::mockPerson(n = 4, seed = 1) |>
+    omock::mockObservationPeriod(seed = 1)
   cdm_local$concept <- dplyr::tibble(
     "concept_id" = c(1, 2),
     "concept_name" = c("my concept 1", "my concept 2"),
@@ -343,8 +368,8 @@ test_that("out of observation", {
   # event starts out, end in (subject 3)
   # no concept 2
   cdm_local <- omock::mockCdmReference() |>
-    omock::mockPerson(n = 4) |>
-    omock::mockObservationPeriod()
+    omock::mockPerson(n = 4, seed = 1) |>
+    omock::mockObservationPeriod(seed = 1)
   cdm_local$concept <- dplyr::tibble(
     "concept_id" = c(1, 2),
     "concept_name" = c("my concept 1", "my concept 2"),
@@ -384,8 +409,8 @@ test_that("out of observation", {
   # out of observation (subject 3)
   # overlapping (subject 4)
   cdm_local <- omock::mockCdmReference() |>
-    omock::mockPerson(n = 4) |>
-    omock::mockObservationPeriod()
+    omock::mockPerson(n = 4, seed = 1) |>
+    omock::mockObservationPeriod(seed = 1)
   cdm_local$concept <- dplyr::tibble(
     "concept_id" = c(1, 2),
     "concept_name" = c("my concept 1", "my concept 2"),
@@ -473,3 +498,195 @@ test_that("table not present in the cdm", {
 
   PatientProfiles::mockDisconnect(cdm)
 })
+
+test_that("cohort exit as event start date", {
+  cdm <- omock::mockCdmReference() |>
+    omock::mockCdmFromTables(tables = list("cohort" = dplyr::tibble(
+      "cohort_definition_id" = 1L,
+      "subject_id" = c(1L, 2L, 3L),
+      "cohort_start_date" = as.Date("2020-01-01"),
+      "cohort_end_date" = as.Date("2029-12-31")
+    )))
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "concept", table = dplyr::tibble(
+      "concept_id" = 1L,
+      "concept_name" = "my concept",
+      "domain_id" = "drug",
+      "vocabulary_id" = NA,
+      "concept_class_id" = NA,
+      "concept_code" = NA,
+      "valid_start_date" = NA,
+      "valid_end_date" = NA
+    )
+  )
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "drug_exposure", table = dplyr::tibble(
+      "drug_exposure_id" = c(1L, 2L),
+      "person_id" = c(1L, 1L),
+      "drug_concept_id" = c(1L, 1L),
+      "drug_exposure_start_date" = as.Date(c("2020-01-01",
+                                     "2020-01-04")),
+      "drug_exposure_end_date" = as.Date(c("2020-01-10",
+                                           "2020-01-14")),
+      "drug_type_concept_id" = 1L
+    ) )
+
+  cdm <- cdm |> copyCdm()
+
+  expect_no_error(cdm$cohort_1 <- conceptCohort(cdm = cdm,
+                                          conceptSet = list(a = 1L),
+                                          name = "cohort_1",
+                                          exit = "event_end_date"))
+ # one entry from first start to second end
+   expect_true(nrow(cdm$cohort_1 |>
+    dplyr::collect()) == 1)
+   expect_true(cdm$cohort_1 |>
+     dplyr::pull("cohort_start_date") == as.Date(c("2020-01-01")))
+   expect_true(cdm$cohort_1 |>
+                 dplyr::pull("cohort_end_date") == as.Date(c("2020-01-14")))
+
+ # exit as event start
+ expect_no_error(cdm$cohort_1 <- conceptCohort(cdm = cdm,
+                                               conceptSet = list(a = 1),
+                                               name = "cohort_1",
+                                               exit = "event_start_date"))
+ expect_true(nrow(cdm$cohort_1 |>
+                    dplyr::collect()) == 2)
+ expect_identical(sort(as.Date(cdm$cohort_1 |>
+               dplyr::pull("cohort_start_date"))),
+               c(as.Date("2020-01-01"),
+                       "2020-01-04"))
+ expect_identical(sort(as.Date(cdm$cohort_1 |>
+                                 dplyr::pull("cohort_end_date"))),
+                  c(as.Date("2020-01-01"),
+                    "2020-01-04"))
+
+ # expected error
+ expect_error(cdm$cohort_1 <- conceptCohort(cdm = cdm,
+                                               conceptSet = list(a = 1L),
+                                               name = "cohort_1",
+                                               exit = "not_an_option"))
+
+
+})
+
+test_that("use source field concepts", {
+  cdm <- omock::mockCdmReference() |>
+    omock::mockCdmFromTables(tables = list("cohort" = dplyr::tibble(
+      "cohort_definition_id" = 1L,
+      "subject_id" = c(1L, 2L, 3L),
+      "cohort_start_date" = as.Date("2020-01-01"),
+      "cohort_end_date" = as.Date("2029-12-31")
+    )))
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "concept", table = dplyr::tibble(
+      "concept_id" = 99L,
+      "concept_name" = "my_non_standard_concept",
+      "domain_id" = "drug",
+      "vocabulary_id" = NA,
+      "concept_class_id" = NA,
+      "concept_code" = NA,
+      "valid_start_date" = NA,
+      "valid_end_date" = NA
+    )
+  )
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "drug_exposure", table = dplyr::tibble(
+      "drug_exposure_id" = c(1L, 2L),
+      "person_id" = c(1L, 1L),
+      "drug_concept_id" = c(1L, 1L),
+      "drug_exposure_start_date" = as.Date(c("2020-01-01",
+                                             "2020-01-04")),
+      "drug_exposure_end_date" = as.Date(c("2020-01-10",
+                                           "2020-01-14")),
+      "drug_type_concept_id" = 1L,
+      "drug_source_concept_id" = 99L
+    ) )
+
+  cdm <- cdm |> copyCdm()
+
+  # no records if we only look at standard concepts
+  expect_no_error(cdm$cohort_1a <- conceptCohort(cdm = cdm,
+                                                conceptSet = list(a = 99L),
+                                                name = "cohort_1a",
+                                                exit = "event_end_date",
+                                                useSourceFields = FALSE))
+  expect_true(nrow(cdm$cohort_1a |>
+    dplyr::collect()) == 0)
+
+  # records if we also look at source fields
+  expect_no_error(cdm$cohort_1b <- conceptCohort(cdm = cdm,
+                                                 conceptSet = list(a = 99L),
+                                                 name = "cohort_1b",
+                                                 exit = "event_end_date",
+                                                 useSourceFields = TRUE))
+  expect_true(nrow(cdm$cohort_1b |>
+                     dplyr::collect()) > 0)
+
+
+})
+
+test_that("missing event end dates", {
+  testthat::skip_on_cran()
+  cdm <- omock::mockCdmReference() |>
+    omock::mockCdmFromTables(tables = list("cohort" = dplyr::tibble(
+      "cohort_definition_id" = 1,
+      "subject_id" = c(1, 2, 3),
+      "cohort_start_date" = as.Date("2020-01-01"),
+      "cohort_end_date" = as.Date("2029-12-31")
+    )))
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "concept", table = dplyr::tibble(
+      "concept_id" = 1,
+      "concept_name" = "my concept",
+      "domain_id" = "drUg",
+      "vocabulary_id" = NA,
+      "concept_class_id" = NA,
+      "concept_code" = NA,
+      "valid_start_date" = NA,
+      "valid_end_date" = NA
+    )
+  )
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "drug_exposure", table = dplyr::tibble(
+      "drug_exposure_id" = 1:11,
+      "person_id" = c(1, 1, 1, 1, 2, 2, 3, 1, 1, 1, 1),
+      "drug_concept_id" = c(1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1),
+      "drug_exposure_start_date" = c(0, 300, 1500, 750, 10, 800, 150, 1800, 1801, 1802, 1803),
+      "drug_exposure_end_date" = c(400, 800, 1600, 1550, 2000, 1000, 600, 1801, 1802, 1803, 1804),
+      "drug_type_concept_id" = 1
+    ) |>
+      dplyr::mutate(
+        "drug_exposure_start_date" = as.Date(.data$drug_exposure_start_date, origin = "2020-01-01"),
+        "drug_exposure_end_date" = as.Date(.data$drug_exposure_end_date, origin = "2020-01-01")
+      )
+  )
+  cdm <- cdm |> copyCdm()
+  expect_no_error(cohort <- conceptCohort(cdm = cdm, conceptSet = list(a = 1), name = "cohort"))
+  startCount <- cohortCount(cohort) |>
+    dplyr::pull("number_subjects")
+
+  # with missing end dates we should have the same subject count
+  # as their missing end date will have been replaced by the start date
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "drug_exposure", table = dplyr::tibble(
+      "drug_exposure_id" = 1:11,
+      "person_id" = c(1, 1, 1, 1, 2, 2, 3, 1, 1, 1, 1),
+      "drug_concept_id" = c(1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1),
+      "drug_exposure_start_date" = c(0, 300, 1500, 750, 10, 800, 150, 1800, 1801, 1802, 1803),
+      "drug_exposure_end_date" = as.Date(NA),
+      "drug_type_concept_id" = 1
+    ) |>
+      dplyr::mutate(
+        "drug_exposure_start_date" = as.Date(.data$drug_exposure_start_date, origin = "2020-01-01")
+      )
+  )
+  expect_no_error(cohort <- conceptCohort(cdm = cdm, conceptSet = list(a = 1), name = "cohort"))
+  endCount <- cohortCount(cohort) |>
+    dplyr::pull("number_subjects")
+
+ expect_identical(startCount, endCount)
+
+
+  PatientProfiles::mockDisconnect(cdm)
+})
