@@ -1,8 +1,8 @@
 test_that("requiring presence in another cohort", {
   cdm_local <- omock::mockCdmReference() |>
-    omock::mockPerson(n = 4) |>
-    omock::mockObservationPeriod() |>
-    omock::mockCohort(name = c("cohort1"), numberCohorts = 2) |>
+    omock::mockPerson(n = 4, seed = 1) |>
+    omock::mockObservationPeriod(seed = 1) |>
+    omock::mockCohort(name = c("cohort1"), numberCohorts = 2, seed = 1) |>
     omock::mockCohort(name = c("cohort2"), numberCohorts = 2, seed = 2)
   cdm <- cdm_local |> copyCdm()
 
@@ -69,9 +69,9 @@ test_that("requiring presence in another cohort", {
                                             window = c(0, Inf),
                                             censorDate = "cohort_end_date",
                                             name = "cohort5")
-  expect_true(all(cdm$cohort5 |> dplyr::pull("cohort_start_date") == c("2015-04-14", "2015-02-23")))
-  expect_true(all(cdm$cohort5 |> dplyr::pull("subject_id") == c("3", "3")))
-  expect_true(all(cdm$cohort5 |> dplyr::pull("cohort_definition_id") == c("1", "2")))
+  expect_true(all(cdm$cohort5 |> dplyr::pull("cohort_start_date") == c("2003-05-08", "2000-06-17", "2004-12-12")))
+  expect_true(all(cdm$cohort5 |> dplyr::pull("subject_id") == c("1", "1", "1")))
+  expect_true(all(cdm$cohort5 |> dplyr::pull("cohort_definition_id") == c("1", "2", "2")))
   expect_true(all(omopgenerics::attrition(cdm$cohort5)$reason ==
                     c("Initial qualifying events",
                       "In cohort cohort_2 between 0 & Inf days relative to cohort_start_date between 1 and Inf times, censoring at cohort_end_date",
@@ -80,17 +80,17 @@ test_that("requiring presence in another cohort", {
 
   # cohort Id
   cdm$cohort6 <- requireCohortIntersect(cohort = cdm$cohort2,
-                                            cohortId = 2,
+                                            cohortId = "cohort_2",
                                             targetCohortTable = "cohort1",
                                             targetCohortId = 1,
                                             window = c(0, Inf),
                                             censorDate = "cohort_end_date",
                                             name = "cohort6")
   expect_true(all(cdm$cohort6 |> dplyr::pull("cohort_start_date") |> sort() ==
-                    c("1993-01-06", "1999-06-23", "2000-03-06", "2003-07-21",
-                      "2015-02-23", "2015-04-14")))
-  expect_true(all(cdm$cohort6 |> dplyr::pull("subject_id") |> sort() == c("1", "2", "2", "3", "3", "4")))
-  expect_true(all(cdm$cohort6 |> dplyr::pull("cohort_definition_id") |> sort() == c(rep("1", 4), rep("2", 2))))
+                    c("1999-07-11", "2000-01-11", "2000-05-28", "2000-06-17",
+                      "2003-05-08", "2004-12-12", "2015-01-25", "2015-02-02")))
+  expect_true(all(cdm$cohort6 |> dplyr::pull("subject_id") |> sort() == c("1","1","1", "2", "2", "2", "3", "3")))
+  expect_true(all(cdm$cohort6 |> dplyr::pull("cohort_definition_id") |> sort() == c(rep("1", 4), rep("2", 4))))
   expect_true(all(omopgenerics::attrition(cdm$cohort6)$reason ==
                     c("Initial qualifying events",
                       "Initial qualifying events",
@@ -105,10 +105,9 @@ test_that("requiring presence in another cohort", {
                                             censorDate = "cohort_end_date",
                                             name = "cohort7")
   expect_true(all(cdm$cohort7 |> dplyr::pull("cohort_start_date") |> sort() ==
-                    c("1999-06-23", "2000-03-06", "2003-07-21", "2015-02-02",
-                      "2015-02-08", "2015-04-14")))
-  expect_true(all(cdm$cohort7 |> dplyr::pull("subject_id") |> sort() == c("1", "2", "2", "3", "3", "3")))
-  expect_true(all(cdm$cohort7 |> dplyr::pull("cohort_definition_id") |> sort() == c(rep("1", 4), rep("2", 2))))
+                    c("2000-01-11", "2000-05-28", "2003-05-08", "2015-01-25")))
+  expect_true(all(cdm$cohort7 |> dplyr::pull("subject_id") |> sort() == c("1", "2", "2", "3")))
+  expect_true(all(cdm$cohort7 |> dplyr::pull("cohort_definition_id") |> sort() == c(rep("1", 4))))
   expect_true(all(omopgenerics::attrition(cdm$cohort7)$reason ==
                     c("Initial qualifying events",
                       "Initial qualifying events",
@@ -143,9 +142,9 @@ test_that("requiring presence in another cohort", {
 test_that("requiring absence in another cohort", {
   testthat::skip_on_cran()
   cdm_local <- omock::mockCdmReference() |>
-    omock::mockPerson(n = 4) |>
-    omock::mockObservationPeriod() |>
-    omock::mockCohort(name = c("cohort1"), numberCohorts = 2) |>
+    omock::mockPerson(n = 4,seed = 1) |>
+    omock::mockObservationPeriod(seed = 1) |>
+    omock::mockCohort(name = c("cohort1"), numberCohorts = 2, seed = 1) |>
     omock::mockCohort(name = c("cohort2"), numberCohorts = 2, seed = 2)
   cdm <- cdm_local |> copyCdm()
 
@@ -201,7 +200,7 @@ test_that("different intersection count requirements", {
                          as.Date('2019-01-06'))
   )
   cdm_local <- omock::mockCdmReference() |> omock::mockCdmFromTables(tables = list("cohort1" = cohort1,
-                                                                     "cohort2" = cohort2))
+                                                                     "cohort2" = cohort2), seed = 1)
   cdm <- cdm_local |> copyCdm()
 
   # no intersections - people not in cohort2
